#!/bin/bash
 
######################################################################
#                                                                    #
# autoreply script for integration into postfix server process       #
#                                                                    #
# Author:     tobi <tobster@brain-force.ch>                          #
# Version:    0.2 (bug fix)                                          #
# Date:       05/09/11                                               #
# License:    GPL Version 3 (contact author prior to commercial use) #
# Depends:    bash (get it via ipkg)                                 #
#             egrep (should be in ipkg coreutils or similar)         #
#                                                                    #
# Important:  You probably need to adjust chmod on the log file.     #
#             This script SHOULD NEVER run as root and therefore the #
#             logfile needs to be created manually by root. The user #
#             running autoreply need write access on that logfile.   #
#                                                                    #
#             Check all paths in the script as the default paths are #
#             for a debian. Change them to your enviroment!          #
#                                                                    #
#             create autoreply.txt and autoreply.html manually.      #
#             these files expect the content as valid (ex correct    #
#             mime headers and transfer-encodings) mime parts        #
#                                                                    #
# History:    * 04/08/10 initial version 0.1 as beta                 #
#             * 06/08/10 minor bug fixes                             #
#             * 10/08/10 support for template files added            #
#             * 11/08/10 version 0.2 as stable                       #
#             * 05/09/11 minor changes. trim.php no longer needed    #
#             * 05/09/11 bug in rfc attachment fixed                 #
#                                                                    #
# ToDo:       * support for txt and html templates (added in 0.2)    #
#             * original message as rfc822 compatible attachment     #
#                                                                    #
# Summary:    A small autoreply script that sends messages on every  #
#             mail received ex if you use a info address and want to #
#             confirm every message that is sent there.              #
#             Some tests are performed before sending the mail:      #
#                                                                    #
#              * is the mail coming from a mailing list?             #
#              * are there typical headers for bulk messages?        #
#              * can the rcpt address been found in msg headers?     #
#                                                                    #
# Usage:      echo msg | autreply sender reciever                    #
# * sender:   sender of the original msg. The one who will receive   #
#             the autoreply                                          #
# * receiver: the receiver of the original msg. Will be used as      #
#             sender of the autoreply message                        #
# * stdin:    on stdin the content of the original msg is expected   #
#                                                                    #
######################################################################
 
 
if test "$1" = "-h"; then
 echo "*************************************************************"
 echo "*                                                           *"
 echo "* Usage:    autoreply sender reciever                       *"
 echo "* sender:   the original sender of the mail                 *"
 echo "* reciever: the original reciever of the mail               *"
 echo "* stdin:    on stdin the content of the mail is expected    *"
 echo "*                                                           *"
 echo "*************************************************************"
 exit
fi
 
msg=""
log=/var/log/autoreply.log
err=''
touch $log
 
while read x1
do
 msg="$msg\n$x1"
done
 
sendReply ()
{
 mail='/usr/sbin/sendmail'
 str="From: $2 <$2>\n"
 str=$str"To: <"$1">\n"
 str=$str"Content-Type: multipart/mixed; boundary=\"grenze\"\n"
 str=$str"Subject: Your request to "$2"\n\n"
 str=$str"--END\n"
 str=$str"Content-Type: multipart/alternative; boundary=\"alternative\"\n"
 eval "t=\"$(cat /etc/postfix/autoreply.txt)\""
 str=$str"\n--alternative\n"
 str=$str$t
 str=$str"\n\n--alternative\n"
 eval "t=\"$(cat /etc/postfix/autoreply.html)\""
 str=$str$t"\n\n--alternative--\n\n--END\n"
 str=$str"Content-Type: message/rfc822\nContent-Disposition: attachment;filename=message.eml;\nContent-Transfer-Encoding: 7bit\n\n$msg\n\n--END--"
 echo -e "$str" | $mail -f "$2" -t "$1"
 exit
}
 
err=$(echo -e $msg | grep -i ^Auto-Submitted: | grep -iv "no" )
t=$?
if test $t -eq 0 ; then
 echo -e $(date +"%b %_d %T")"\tMessage has Auto-Submitted Headers with a value other than \"no\"\n$1\t$2" >> $log
 exit
fi
 
err=$(echo -e $msg | grep -i ^Precedence: | grep -i "junk")
t=$?
if test $t -eq 0 ; then
 echo -e $(date +"%b %_d %T")"\tMessages has Precedence \"junk\" header\n$1\t$2" >> $log
 exit
fi
 
err=$(echo -e $msg | grep -i ^Precedence: | grep -i "bulk")
t=$?
if test $t -eq 0 ; then
 echo -e $(date +"%b %_d %T")"\tMessages has Precedence header \"bulk\"\n$1\t$2" >> $log
 exit
fi
 
err=$(echo -e $msg | grep -i ^Precedence: | grep -i "list")
t=$?
if test $t -eq 0 ; then
 echo -e $(date +"%b %_d %T")"\tMessage has Precedence header with \"list\"\n$1\t$2" >> $log
 exit
fi
 
err=$(echo $1 | egrep -i mailer-daemon\|listserv\|majordomo\|owner-\|\-request)
t=$?
if test $t -eq 0 ; then
 echo -e $(date +"%b %_d %T")"\tMessage seems to be from a mailing list\n$1\t$2" >> $log
 exit
fi
 
if test "$1" = "$2" ; then
 echo -e $(date +"%b %_d %T")"\tFehler: Sender und Empfaenger sind gleich\n$1\t$2" >> $log
 exit
fi
 
err=$(echo -e $msg | grep -i ^To: | grep "$2")
t=$?
if test $t -eq 0; then
 sendReply $1 $2 "$msg"
fi
 
err=$(echo -e $msg | grep -i ^Cc: | grep "$2")
t=$?
if test $t -eq 0; then
 sendReply $1 $2 "$msg"
fi
 
err=$(echo -e $msg | grep -i ^Bcc: | grep "$2")
t=$?
if test $t -eq 0; then
 sendReply $1 $2 "$msg"
fi
echo -e $(date +"%b %_d %T")"\trcpt not found in headers (To, Cc or Bcc)\n$1\t$2" >> $log
